@@ -66,7 +66,7 @@ else {
 # then we need the main-window
 $mw = MainWindow -> new;
 $mw -> title("cd-circleprint");
-# Something which some windowmanager semems to need
+# Something which some window managers seem to need
 $mw -> geometry("+0+0");
 
 # some key-bindings
@@ -301,7 +301,7 @@ sub clear_textfields {
 }
 #######################
 sub configure_fonts {
-  # It is not possible to use the size from the perl-tk fonts, because the perl-tk
+  # It is not possible to use the size from the perl-tk fonts, because perl-tk
   # uses the nearest matching font on the system but we want exact PostScript fonts
 
   my $j = shift;
@@ -355,17 +355,17 @@ sub defaults {
   # Name of the resulting PS-file
   $psfile = "/tmp/cd-circleprint.ps";
 
-  # Number of label on a sheet (very incomplete use of this variable)
+  # Number of labels on a sheet (very incomplete use of this variable)
   $number_of_labels = 2;
 
   # A variable to define the backround which is treated as an additional circle or textfield
   $number_of_background = 99;
 
   # which previewer
-  $viewer = "/usr/X11R6/bin/gv";
+  $viewer = "gv";
 
   # which converter
-  $converter = "/usr/bin/convert";
+  $converter = "convert";
 
   # defaults for the circles in mm
   $radius_outer = 60;
@@ -554,8 +554,9 @@ sub info_window {
   my $info_window = MainWindow -> new;
   my $text = $info_window -> Text(-font => "r16") -> pack;
 
-  $text -> insert('end', "cd-circleprint, a simple perl script by Matthias Kabel <matthias.kabel\@tyche.de>\n");
-  $text -> insert('end', "The following people has send me patches which improved the program:\n\n" );
+  $text -> insert('end', "cd-circleprint, a simple perl script by Colin Tuckley <colintu\@users.sourceforge.net>\n");
+  $text -> insert('end', "cd-circleprint originally written by Matthias Kabel <matthias.kabel\@tyche.de>\n");
+  $text -> insert('end', "The following people have sent me patches which improved the program:\n\n" );
   $text -> insert('end', "* Dave Regan <regan\@ao.com>\n\n");
   $text -> insert('end', "cd-circleprint is published under the GNU public license\n");
   $text -> insert('end', "You should have this license in your distribution\n");
@@ -596,7 +597,7 @@ sub read_configuration {
       }
       else {
 	print "Oops, there was something wrong\n";
-	## We need really a better routine here
+	## We really need a better routine here
       }
     }
   }
@@ -634,6 +635,7 @@ sub print_circles {
 
     my $dummy;
     my $name;
+    my $dir;
     my $ext;
     my $path;
   my $label_no;
@@ -1050,7 +1052,7 @@ sub print_textfields {
   for ( $i=0; $i<4;$i++) {
     for ($label_no=0; $label_no < $number_of_labels;$label_no++  ) {
       $x_position = $begin_from_left[$label_no]  + $radius_outer + sin($i * $pi/2) *(($radius_outer -$radius_inner)/2);
-      print $x_position,"\n";
+      print "X-pos=", $x_position, "\n";
       $x_position += 5 if ($i == 1);
       $x_position =  $begin_from_left[$label_no]  +5  if ($i == 3); # shift the x-position right
       print "$label_no: $x_position\n";
@@ -1067,7 +1069,7 @@ sub print_textfields {
 	print PS_FILE "(", $t,")\n";
 	print PS_FILE "$textwidth[$i] mm \n";
 	print PS_FILE "{\n$x_position mm YLine moveto\n";
-	# Ok, here we are, we have to correct the current point by the half of
+	# Ok, here we are, we have to correct the current point by half of
 	# the fontsize
  	print PS_FILE "\n0 -", $scalefont[$i+4]/2 , " rmoveto\n";
 	# Only the textfields above and below the hole in the middle should be centered
@@ -1102,7 +1104,7 @@ sub print_ticks {
   print PS_FILE "/Helvetica findfont 12 scalefont setfont\n";
   print PS_FILE $begin_from_left[0] / 2 + 10," mm ", 2*$radius_outer + $delta / 2 + $begin_from_bottom , " mm moveto\n";
   print PS_FILE "90 rotate\n";
-  print PS_FILE "(All complaints to matthias\@tyche.de please) center show\n";
+  print PS_FILE "(All comments to colintu\@users.sourceforge.net please) center show\n";
   print PS_FILE "grestore\n";
 
   print PS_FILE "gsave\n";
@@ -1141,7 +1143,7 @@ sub print_ticks {
   }
 
 
-  # next ticks on the top of the page
+  # next ticks at the top of the page
   print PS_FILE "0 ", 2*$radius_outer + $delta , " mm translate\n";
 
   ### correct this with pagelength ####################
@@ -1200,7 +1202,7 @@ sub get_bounding_box() {
     close ($eps_file);
   }
   else {
-    warning_window("There seems no bounding box in $eps_file\nHope for the best\n");
+    warning_window("There seems to be no bounding box in $eps_file\nHope for the best\n");
   }
 }
 
@@ -1661,7 +1663,7 @@ sub set_distances {
 
     for (my $label_no = 0;$label_no < $number_of_labels; $label_no++ ) {
       $fwt -> Entry(-textvariable => \$begin_from_left[$label_no],
-		    -text => "Labeltext"
+		    -text => "Labeltext",
 		   -width => '5') -> pack(-side => 'bottom');
       $fwt -> Scale(-label => "move circle $label_no horizontal",
 		    -orient => 'horizontal',
@@ -1786,7 +1788,7 @@ sub dummy {
 
 =head1 NAME
 
-cd-circleprint - create a nice round shaped label for a CD
+cd-circleprint - create a nice round label for a CD
 
 THIS MANUAL PAGE IS VERY INCOMPLETE
 
@@ -1796,18 +1798,18 @@ Please play around with the program to see all options
 
 cd-circleprint FILE
 
-You can specify an alternate configurationfile in the commandline
+You can specify an alternate configuration file on the command line
 
 =head1 DESCRIPTION
 
-cd-circleprint prints two round shaped labels for CDs. It uses up to four lines of text for each
+cd-circleprint prints two round labels for CDs. It uses up to four lines of text for each
 label. This text is printed in arcs so the text can be much longer than if it were in straight lines.
-Furthermore there are four textfields for each label.
+Furthermore there are four text fields for each label.
 
 The output is in PostScript, this should work on most systems.
 
 You can choose the font, size, and color of the text for each field separately, and you
-can choose the background color of the label itself. If you wish more complicated backgrounds
+can choose the background colour of the label itself. If you wish more complicated backgrounds
 or color effects you can save a label and use in any graphic program which can read
 PostScript. (I suggest "The Gimp")
 
@@ -1815,16 +1817,16 @@ PostScript. (I suggest "The Gimp")
 
 All layout is done in PostScript, this should work on most systems.
 
-The result of the layout are two cd-labels on one sheet of paper. In each label there are two
+The result of the layout are two cd-labels on one sheet of paper. On each label there are two
 convex and two concave lines of text. If you have a very long line of text, you can use only
 one line and make it longer.  There are no limits to the length of text.
 However, after 360 degrees the ends of the text will overlap.
 
-There are also four textfields in each label with normal horizontal
-lines of text.  These textfields are specified in clockwise order:
+There are also four text fields on each label with normal horizontal
+lines of text.  These text fields are specified in clockwise order:
 above, right, below, and left of the central hole.
 
-The colors are done in the RGB-model of PostScript, you can choose them for each line and 
+The colours are done in the RGB-model of PostScript, you can choose them for each line and 
 the background of the label independently.
 
 You can move the circles around the sheet to fit them on most types of label-sheets.
@@ -1834,17 +1836,17 @@ You can also squeeze or stretch the whole thing to correct small errors of your
 =head1 USING
 
 After starting the program you can see sixteen text-entry fields divided into two blocks. 
-The upper block is for the textfields, the lower block for the arcs.
+The upper block is for the text fields, the lower block for the arcs.
 
-Each label has four textfields and four arcs.
+Each label has four text fields and four arcs.
 The first two lines are for the upper arcs on the label and the last two for the lower arcs.
 
 Write your text in the fields (support for cddb is on the TODO list)
-and press the button "label" or press Control-l in the menu on top of the window. This button creates a file
-/tmp/cd-circleprint.ps which can be previewed with an PostScript viewer. There is a button to start
+and press the button "label" or press Control-l in the menu at the top of the window. This button creates a file
+/tmp/cd-circleprint.ps which can be previewed with a PostScript viewer. There is a button to start
 your favorite previewer or you can press Control-p.
 
-Font attributes and colors can changed interactively with the menu.
+Font attributes and colours can changed interactively with the menu.
 
 =head2 Shortcuts
 	Control-l: write the label in /tmp
@@ -1855,18 +1857,18 @@ Font attributes and colors can changed interactively with the menu.
 =item B<Label-Options>
 
 =item I<Font-attributes>
-Here you can change fontfamily, fontsize, font-color and the backgroundcolor interactively, all
+Here you can change font family, font size, font-colour and the background colour interactively, all
 changes should take effect immediately in the text entry fields.
 
-Be carefully, perl-tk uses the nearest match for the font. Maybe the labels will look different on your printer.
+Be carefull, perl-tk uses the nearest match for the font. The labels may look different on your printer.
 
 =item I<Radii>
 There are many types of CD-labels, so here you are able to correct the size of the inner circle.
 
-Additional, you can change the radius for all four text-lines.
+Additionaly, you can change the radius for all four text-lines.
 
 =item I<Size>
-Some printers are not working correctly with circles and produce a ellipse. So you can squeeze or stretch
+Some printers do not work correctly with circles and produce an ellipse. So you can squeeze or stretch
 the whole page to get perfect circles with your printer.
 
 =item I<tickmarks>
@@ -1875,7 +1877,7 @@ easier, you can print some tickmarks on the page to measure the distances.
 If you have the correct values, you don't need these tickmarks any more and can save some ink.
 
 =item I<distances>
-You can move the circles around the page with this menu.
+You can move the circles around the page using this menu.
 
 =item I<graphics>
 You can put an image on the label. This image currently has to be in eps-format.
@@ -1883,7 +1885,7 @@ You can put an image on the label. This image currently has to be in eps-format.
 I thought about automatic scaling, but the program would
 have to know the real size of the visible part of the graphic instead of just the bounding box.
 
-The scaling and shifting should be self-explanatory. The programs get the bounding box of the eps and 
+The scaling and shifting should be self-explanatory. The program gets the bounding box of the eps and 
 puts the image in the middle of the label.
 
 =head1 CONFIGURATION
@@ -1897,8 +1899,8 @@ Not all options are stored now, but I'm working on it.
 There is a global configuration file /etc/cd-circleprint.conf and a local configuration file 
 $HOME/.cd-circleprint.conf
 
-You can specify another configuration file on the commandline, then the default configuration files are ignored.
-For the format of the configuration files take look at them.
+You can specify another configuration file on the command line, in which case the default configuration files are ignored.
+For the format of the configuration files take a look at them.
 Comments start with a # and blank lines are ignored.
 
 The program sets its internal default values, looks for the global configuration and then
@@ -1906,16 +1908,16 @@ for the local configuration file.
 
 =head1 BUGS
 
-There are surely many bugs and much more ugly code but it works.
+There are probably many bugs and much more ugly code but it works.
 Please fix them and send me a patch.
-Any native English speaker who wants to correct the bad English of this man-page would be welcome too.
 Thanks
 
 =head1 AUTHORS
 
-cd-circleprint is written and maintained by Matthias Kabel <matthias.kabel@tyche.de>
+cd-circleprint is written and maintained by Colin Tuckley <colintu@users.sourceforge.net>
+cd-circleprint was originally written by Matthias Kabel <matthias.kabel@tyche.de>
 
-You can find the latest version on http://cd-circle-print.sourceforge.net
+You can find the latest version at http://cd-circle-print.sourceforge.net
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
